@@ -47,6 +47,12 @@
 #define SQL_ATTR_REPLACE_QUOTED_LITERALS 2586
 #endif
 
+#ifndef SQL_ATTR_USE_TRUSTED_CONTEXT
+#define SQL_ATTR_USE_TRUSTED_CONTEXT 2561
+#define SQL_ATTR_TRUSTED_CONTEXT_USERID 2562
+#define SQL_ATTR_TRUSTED_CONTEXT_PASSWORD 2563
+#endif
+
 /* CLI v9.1 FP3 and below has a SQL_ATTR_REPLACE_QUOTED_LITERALS value of 116
  * We need to support both the new and old values for compatibility with older
  * versions of CLI. CLI v9.1 FP4 and beyond changed this value to 2586
